Crate futures_yamux

Crate futures_yamux 

Structs

Flags
The flags field is used to provide additional information related to the message type. The following flags are supported:
Frame
Yamux frame type.
FrameHeaderBuilder
A builder for FrameHeader
Session
A yamux session type for handling the logical streams.
YamuxConn
Yamux connection type with asynchronous api.
YamuxConnState
Yamux connection type with asynchronous api.
YamuxStream
Yamux stream type with asynchronous api.

Enums

Error
Yamux errors type.
FrameHeader
Yamux uses a streaming connection underneath, but imposes a message framing so that it can be shared between many logical streams. Each frame contains a header like:
FrameRestrictionKind
Reason for not being able to build the frame.
FrameType
The type field is used to switch the frame message type. The following message types are supported:
InvalidFrameKind
Reason for not being able to parse the frame.
Reason
Session terminated reason.

Constants

INIT_WINDOW_SIZE
When Yamux is initially starts each stream with a 256KB window size.

Type Aliases

Result
A specialized Result type for yamux operations.